==> vue-tag-group-2.8.0.tgz: package/lib/pc.js <==
import { defineComponent, $prefix, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/tag-group/vue";
import { IconEllipsis } from "@dftvue2-opentiny/vue-icon";
import Popover from "@dftvue2-opentiny/vue-popover";
import Tag from "@dftvue2-opentiny/vue-tag";
import "@dftvue2-opentiny/vue-theme/tag-group/index.css";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "TagGroup",
  components: {
    TinyTag: Tag,
    TinyPopover: Popover,
    IconEllipsis: IconEllipsis()
  },
  props: [].concat(props, ["size", "data", "effect"]),
  emits: ["item-click"],
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "tagGroup",
    staticClass: "tiny-tag-group"
  }, [_vm._l(_vm.data, function(item, i) {
    return _c("tiny-tag", {
      key: item.name + i,
      staticStyle: {
        "margin-right": "8px",
        "margin-bottom": "8px"
      },
      attrs: {
        "size": _vm.size,
        "type": item.type,
        "effect": _vm.effect
      },
      on: {
        "click": function click($event) {
          return _vm.handelItemClick(item, i, $event);
        }
      }
    }, [_vm._v(_vm._s(item.name))]);
  }), _vm.state.showMore ? _c("tiny-popover", {
    attrs: {
      "placement": "top-start",
      "trigger": "hover",
      "width": "auto"
    },
    scopedSlots: _vm._u([{
      key: "reference",
      fn: function fn() {
        return [_c("tiny-tag", {
          ref: "more",
          staticClass: "tiny-tag-group_icon",
          attrs: {
            "size": _vm.size
          }
        }, [_c("icon-ellipsis")], 1)];
      },
      proxy: true
    }], null, false, 4103312066)
  }, [_c("div", _vm._l(_vm.state.hiddenTags, function(tag, i) {
    return _c("tiny-tag", {
      key: tag.name + i,
      staticStyle: {
        "margin-right": "8px",
        "margin-bottom": "8px"
      },
      attrs: {
        "size": _vm.size,
        "type": tag.type
      },
      on: {
        "click": function click($event) {
          return _vm.handelItemClick(tag, _vm.data.length - _vm.state.hiddenTags.length + i, $event);
        }
      }
    }, [_vm._v(_vm._s(tag.name))]);
  }), 1)]) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  pc as default
};

==> vue-tag-group-2.25.0.tgz: package/lib/pc.js <==
import { defineComponent, $prefix, props, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/tag-group/vue';
import { IconEllipsis } from '@opentinyvue/vue-icon';
import Popover from '@opentinyvue/vue-popover';
import Tag from '@opentinyvue/vue-tag';
import '@opentinyvue/vue-theme/tag-group/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  name: $prefix + "TagGroup",
  components: {
    TinyTag: Tag,
    TinyPopover: Popover,
    IconEllipsis: IconEllipsis()
  },
  props: [].concat(props, ["size", "data", "effect"]),
  emits: ["item-click"],
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "tagGroup",
    staticClass: "tiny-tag-group",
    class: {
      "tiny-tag-group-has-more": _vm.state.showMore
    }
  }, [_vm._l(_vm.data, function(item, i) {
    return _c("tiny-tag", {
      key: item.name + i,
      attrs: {
        "size": _vm.size,
        "type": item.type,
        "effect": _vm.effect
      },
      on: {
        "click": function click($event) {
          return _vm.handelItemClick(item, i, $event);
        }
      }
    }, [_vm._v(_vm._s(item.name) + " ")]);
  }), _vm.state.showMore ? _c("tiny-popover", {
    attrs: {
      "placement": "top-start",
      "trigger": "hover",
      "width": "auto",
      "popper-class": "tiny-tag-group-popper"
    },
    scopedSlots: _vm._u([{
      key: "reference",
      fn: function fn() {
        return [_c("tiny-tag", {
          ref: "more",
          staticClass: "tiny-tag-group_icon",
          attrs: {
            "size": _vm.size
          }
        }, [_c("icon-ellipsis")], 1)];
      },
      proxy: true
    }], null, false, 4103312066)
  }, [_c("div", _vm._l(_vm.state.hiddenTags, function(tag, i) {
    return _c("tiny-tag", {
      key: tag.name + i,
      attrs: {
        "size": _vm.size,
        "type": tag.type
      },
      on: {
        "click": function click($event) {
          return _vm.handelItemClick(tag, _vm.data.length - _vm.state.hiddenTags.length + i, $event);
        }
      }
    }, [_vm._v(_vm._s(tag.name) + " ")]);
  }), 1)]) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var pc = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { pc as default };
